@@ -1,7 +1,7 @@
 package Bencher::Formatter::ModuleStartup;
 
-our $DATE = '2016-06-17'; # DATE
-our $VERSION = '1.010'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '1.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ sub munge_result {
     $self->add_field(
         $envres,
         'mod_overhead_time',
-        {after=>'time', unit_of=>'time'},
+        {after=>'time', unit_of=>'time', align=>'number'},
         sub {
             for my $rit (@{$envres->[2]}) {
                 my $rit_baseline = first {
@@ -43,6 +43,7 @@ sub munge_result {
 
     $self->delete_fields(
         $envres,
+        'dataset',
         'rate',
     );
 }
@@ -62,7 +63,7 @@ Bencher::Formatter::ModuleStartup - Munge module_startup results
 
 =head1 VERSION
 
-This document describes version 1.010 of Bencher::Formatter::ModuleStartup (from Perl distribution Bencher-Backend), released on 2016-06-17.
+This document describes version 1.011 of Bencher::Formatter::ModuleStartup (from Perl distribution Bencher-Backend), released on 2016-06-23.
 
 =head1 DESCRIPTION
 
